@@ -4,7 +4,7 @@
         begin                   : Sun Mar 4 2001
         Copyright 2001-2005,2009 Otto Bruggeman <bruggie@gmail.com>
         Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
-        Copyright 2007      Kevin Kofler   <kevin.kofler@chello.at>
+        Copyright 2007-2011 Kevin Kofler   <kevin.kofler@chello.at>
 ****************************************************************************/
 
 /***************************************************************************
@@ -18,13 +18,15 @@
 
 #include "komparenavtreepart.h"
 
+#include <QtGui/QTreeWidgetItemIterator>
+
 #include <kdebug.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
-#include <k3listview.h>
 #include <kaboutdata.h>
 #include <kcomponentdata.h>
+#include <kpluginfactory.h>
 
 #include "difference.h"
 #include "diffmodel.h"
@@ -37,7 +39,7 @@
 
 using namespace Diff2;
 
-KompareNavTreePart::KompareNavTreePart( QWidget* parent, const char* name )
+KompareNavTreePart::KompareNavTreePart( QWidget* parentWidget, QObject* parent, const QVariantList& )
 	: KParts::ReadOnlyPart( parent ),
 	m_splitter( 0 ),
 	m_modelList( 0 ),
@@ -53,44 +55,44 @@ KompareNavTreePart::KompareNavTreePart( QWidget* parent, const char* name )
 	m_destination( "" ),
 	m_info( 0 )
 {
-	setObjectName( name );
-	m_splitter = new QSplitter( Qt::Horizontal );
+	m_splitter = new QSplitter( Qt::Horizontal, parentWidget );
 
 	setWidget( m_splitter );
 
-	m_srcDirTree = new K3ListView( m_splitter );
-	m_srcDirTree->addColumn( i18n("Source Folder") );
+	m_srcDirTree = new QTreeWidget( m_splitter );
+	m_srcDirTree->setHeaderLabel( i18n("Source Folder") );
 	m_srcDirTree->setRootIsDecorated( false );
-	m_srcDirTree->setSorting( 0, true );
+	m_srcDirTree->setSortingEnabled( true );
+	m_srcDirTree->sortByColumn( 0, Qt::AscendingOrder );
 
-	m_destDirTree = new K3ListView( m_splitter );
-	m_destDirTree->addColumn( i18n("Destination Folder") );
+	m_destDirTree = new QTreeWidget( m_splitter );
+	m_destDirTree->setHeaderLabel( i18n("Destination Folder") );
 	m_destDirTree->setRootIsDecorated( false );
-	m_destDirTree->setSorting( 0, true );
+	m_destDirTree->setSortingEnabled( true );
+	m_destDirTree->sortByColumn( 0, Qt::AscendingOrder );
 
-	m_fileList = new K3ListView( m_splitter );
-	m_fileList->addColumn( i18n("Source File") );
-	m_fileList->addColumn( i18n("Destination File") );
+	m_fileList = new QTreeWidget( m_splitter );
+	m_fileList->setHeaderLabels( QStringList() << i18n("Source File") << i18n("Destination File") );
 	m_fileList->setAllColumnsShowFocus( true );
 	m_fileList->setRootIsDecorated( false );
-	m_fileList->setSorting( 0, true );
+	m_fileList->setSortingEnabled( true );
+	m_fileList->sortByColumn( 0, Qt::AscendingOrder );
 
-	m_changesList = new K3ListView( m_splitter );
-	m_changesList->addColumn( i18n("Source Line") );
-	m_changesList->addColumn( i18n("Destination Line") );
-	m_changesList->addColumn( i18n("Difference") );
+	m_changesList = new QTreeWidget( m_splitter );
+	m_changesList->setHeaderLabels( QStringList() << i18n("Source Line") << i18n("Destination Line") << i18n("Difference") );
 	m_changesList->setAllColumnsShowFocus( true );
 	m_changesList->setRootIsDecorated( false );
-	m_changesList->setSorting( 0, true );
+	m_changesList->setSortingEnabled( true );
+	m_changesList->sortByColumn( 0, Qt::AscendingOrder );
 
-	connect( m_srcDirTree, SIGNAL(selectionChanged( Q3ListViewItem* )),
-	         this, SLOT(slotSrcDirTreeSelectionChanged( Q3ListViewItem* )) );
-	connect( m_destDirTree, SIGNAL(selectionChanged( Q3ListViewItem* )),
-	         this, SLOT(slotDestDirTreeSelectionChanged( Q3ListViewItem* )) );
-	connect( m_fileList, SIGNAL(selectionChanged( Q3ListViewItem* )),
-	         this, SLOT(slotFileListSelectionChanged( Q3ListViewItem* )) );
-	connect( m_changesList, SIGNAL(selectionChanged( Q3ListViewItem* )),
-	         this, SLOT(slotChangesListSelectionChanged( Q3ListViewItem* )) );
+	connect( m_srcDirTree, SIGNAL(currentItemChanged( QTreeWidgetItem*, QTreeWidgetItem* )),
+	         this, SLOT(slotSrcDirTreeSelectionChanged( QTreeWidgetItem* )) );
+	connect( m_destDirTree, SIGNAL(currentItemChanged( QTreeWidgetItem*, QTreeWidgetItem* )),
+	         this, SLOT(slotDestDirTreeSelectionChanged( QTreeWidgetItem* )) );
+	connect( m_fileList, SIGNAL(currentItemChanged( QTreeWidgetItem*, QTreeWidgetItem* )),
+	         this, SLOT(slotFileListSelectionChanged( QTreeWidgetItem* )) );
+	connect( m_changesList, SIGNAL(currentItemChanged( QTreeWidgetItem*, QTreeWidgetItem* )),
+	         this, SLOT(slotChangesListSelectionChanged( QTreeWidgetItem* )) );
 }
 
 KompareNavTreePart::~KompareNavTreePart()
@@ -282,18 +284,18 @@ void KompareNavTreePart::slotSetSelection( const DiffModel* model, const Differe
 void KompareNavTreePart::setSelectedDir( const DiffModel* model )
 {
 	KDirLVI* currentDir;
-	currentDir = m_modelToSrcDirItemDict[ (void*)model ];
+	currentDir = m_modelToSrcDirItemDict[ model ];
 	kDebug(8105) << "Manually setting selection in srcdirtree with currentDir = " << currentDir << endl;
 	m_srcDirTree->blockSignals( true );
-	m_srcDirTree->setSelected( currentDir, true );
-	m_srcDirTree->ensureItemVisible( currentDir );
+	m_srcDirTree->setCurrentItem( currentDir );
+	m_srcDirTree->scrollToItem( currentDir );
 	m_srcDirTree->blockSignals( false );
 
-	currentDir = m_modelToDestDirItemDict[ (void*)model ];
+	currentDir = m_modelToDestDirItemDict[ model ];
 	kDebug(8105) << "Manually setting selection in destdirtree with currentDir = " << currentDir << endl;
 	m_destDirTree->blockSignals( true );
-	m_destDirTree->setSelected( currentDir, true );
-	m_destDirTree->ensureItemVisible( currentDir );
+	m_destDirTree->setCurrentItem( currentDir );
+	m_destDirTree->scrollToItem( currentDir );
 	m_destDirTree->blockSignals( false );
 
 	m_fileList->blockSignals( true );
@@ -304,11 +306,11 @@ void KompareNavTreePart::setSelectedDir( const DiffModel* model )
 void KompareNavTreePart::setSelectedFile( const DiffModel* model )
 {
 	KFileLVI* currentFile;
-	currentFile = m_modelToFileItemDict[ (void*)model ];
+	currentFile = m_modelToFileItemDict[ model ];
 	kDebug(8105) << "Manually setting selection in filelist" << endl;
 	m_fileList->blockSignals( true );
-	m_fileList->setSelected( currentFile, true );
-	m_fileList->ensureItemVisible( currentFile );
+	m_fileList->setCurrentItem( currentFile );
+	m_fileList->scrollToItem( currentFile );
 	m_fileList->blockSignals( false );
 
 	m_changesList->blockSignals( true );
@@ -319,11 +321,11 @@ void KompareNavTreePart::setSelectedFile( const DiffModel* model )
 void KompareNavTreePart::setSelectedDifference( const Difference* diff )
 {
 	KChangeLVI* currentDiff;
-	currentDiff = m_diffToChangeItemDict[ (void*)diff ];
+	currentDiff = m_diffToChangeItemDict[ diff ];
 	kDebug(8105) << "Manually setting selection in changeslist to " << currentDiff << endl;
 	m_changesList->blockSignals( true );
-	m_changesList->setSelected( currentDiff, true );
-	m_changesList->ensureItemVisible( currentDiff );
+	m_changesList->setCurrentItem( currentDiff );
+	m_changesList->scrollToItem( currentDiff );
 	m_changesList->blockSignals( false );
 }
 
@@ -338,10 +340,13 @@ void KompareNavTreePart::slotSetSelection( const Difference* diff )
 	}
 }
 
-void KompareNavTreePart::slotSrcDirTreeSelectionChanged( Q3ListViewItem* item )
+void KompareNavTreePart::slotSrcDirTreeSelectionChanged( QTreeWidgetItem* item )
 {
+	if (!item)
+		return;
+
 	kDebug(8105) << "Sent by the sourceDirectoryTree with item = " << item << endl;
-	m_srcDirTree->ensureItemVisible( item );
+	m_srcDirTree->scrollToItem( item );
 	KDirLVI* dir = static_cast<KDirLVI*>(item);
 	// order the dest tree view to set its selected item to the same as here
 	QString path;
@@ -349,17 +354,20 @@ void KompareNavTreePart::slotSrcDirTreeSelectionChanged( Q3ListViewItem* item )
 	path = dir->fullPath( path );
 	KDirLVI* selItem = m_destRootItem->setSelected( path );
 	m_destDirTree->blockSignals( true );
-	m_destDirTree->setSelected( selItem, true );
-	m_destDirTree->ensureItemVisible( selItem );
+	m_destDirTree->setCurrentItem( selItem );
+	m_destDirTree->scrollToItem( selItem );
 	m_destDirTree->blockSignals( false );
 	// fill the changes list
 	dir->fillFileList( m_fileList, &m_modelToFileItemDict );
 }
 
-void KompareNavTreePart::slotDestDirTreeSelectionChanged( Q3ListViewItem* item )
+void KompareNavTreePart::slotDestDirTreeSelectionChanged( QTreeWidgetItem* item )
 {
+	if (!item)
+		return;
+
 	kDebug(8105) << "Sent by the destinationDirectoryTree with item = " << item << endl;
-	m_destDirTree->ensureItemVisible( item );
+	m_destDirTree->scrollToItem( item );
 	KDirLVI* dir = static_cast<KDirLVI*>(item);
 	// order the src tree view to set its selected item to the same as here
 	QString path;
@@ -367,15 +375,18 @@ void KompareNavTreePart::slotDestDirTreeSelectionChanged( Q3ListViewItem* item )
 	path = dir->fullPath( path );
 	KDirLVI* selItem = m_srcRootItem->setSelected( path );
 	m_srcDirTree->blockSignals( true );
-	m_srcDirTree->setSelected( selItem, true );
-	m_srcDirTree->ensureItemVisible( selItem );
+	m_srcDirTree->setCurrentItem( selItem );
+	m_srcDirTree->scrollToItem( selItem );
 	m_srcDirTree->blockSignals( false );
 	// fill the changes list
 	dir->fillFileList( m_fileList, &m_modelToFileItemDict );
 }
 
-void KompareNavTreePart::slotFileListSelectionChanged( Q3ListViewItem* item )
+void KompareNavTreePart::slotFileListSelectionChanged( QTreeWidgetItem* item )
 {
+	if (!item)
+		return;
+
 	kDebug(8105) << "Sent by the fileList with item = " << item << endl;
 
 	KFileLVI* file = static_cast<KFileLVI*>(item);
@@ -384,17 +395,20 @@ void KompareNavTreePart::slotFileListSelectionChanged( Q3ListViewItem* item )
 	file->fillChangesList( m_changesList, &m_diffToChangeItemDict );
 	m_changesList->blockSignals( false );
 
-	if ( m_changesList->selectedItem() )
+	if ( m_changesList->currentItem() )
 	{
 		// FIXME: This is ugly...
-		m_selectedDifference = (static_cast<KChangeLVI*>(m_changesList->selectedItem()))->difference();
+		m_selectedDifference = (static_cast<KChangeLVI*>(m_changesList->currentItem()))->difference();
 	}
 
 	emit selectionChanged( m_selectedModel, m_selectedDifference );
 }
 
-void KompareNavTreePart::slotChangesListSelectionChanged( Q3ListViewItem* item )
+void KompareNavTreePart::slotChangesListSelectionChanged( QTreeWidgetItem* item )
 {
+	if (!item)
+		return;
+
 	kDebug(8105) << "Sent by the changesList" << endl;
 
 	KChangeLVI* change = static_cast<KChangeLVI*>(item);
@@ -405,27 +419,28 @@ void KompareNavTreePart::slotChangesListSelectionChanged( Q3ListViewItem* item )
 
 void KompareNavTreePart::slotApplyDifference( bool /*apply*/ )
 {
-	KChangeLVI* clvi = m_diffToChangeItemDict[(void*)m_selectedDifference];
+	KChangeLVI* clvi = m_diffToChangeItemDict[m_selectedDifference];
 	if ( clvi )
 		clvi->setDifferenceText();
 }
 
 void KompareNavTreePart::slotApplyAllDifferences( bool /*apply*/ )
 {
-	Q3PtrDictIterator<KChangeLVI> it( m_diffToChangeItemDict );
+	QHash<const Diff2::Difference*, KChangeLVI*>::ConstIterator it = m_diffToChangeItemDict.constBegin();
+	QHash<const Diff2::Difference*, KChangeLVI*>::ConstIterator end = m_diffToChangeItemDict.constEnd();
 
 	kDebug(8105) << "m_diffToChangeItemDict.count() = " << m_diffToChangeItemDict.count() << endl;
 
-	for ( ; it.current(); ++it )
+	for ( ; it != end ; ++it )
 	{
-		it.current()->setDifferenceText();
+		it.value()->setDifferenceText();
 	}
 }
 
 void KompareNavTreePart::slotApplyDifference( const Difference* diff, bool /*apply*/ )
 {
 	// this applies to the currently selected difference
-	KChangeLVI* clvi = m_diffToChangeItemDict[(void*)diff];
+	KChangeLVI* clvi = m_diffToChangeItemDict[diff];
 	if ( clvi )
 		clvi->setDifferenceText();
 }
@@ -468,7 +483,7 @@ void KChangeLVI::setDifferenceText()
 	setText( 2, text );
 }
 
-KChangeLVI::KChangeLVI( K3ListView* parent, Difference* diff ) : K3ListViewItem( parent )
+KChangeLVI::KChangeLVI( QTreeWidget* parent, Difference* diff ) : QTreeWidgetItem( parent )
 {
 	m_difference = diff;
 
@@ -478,31 +493,23 @@ KChangeLVI::KChangeLVI( K3ListView* parent, Difference* diff ) : K3ListViewItem(
 	setDifferenceText();
 }
 
-int KChangeLVI::compare( Q3ListViewItem* item, int column, bool ascending ) const
+bool KChangeLVI::operator<( const QTreeWidgetItem& item ) const
 {
-	if ( ascending )
-	{
-		if ( this->text(column).length() < item->text(column).length() )
-			return -1;
-		if ( this->text(column).length() > item->text(column).length() )
-			return 1;
-	}
-	else
-	{
-		if ( this->text(column).length() > item->text(column).length() )
-			return -1;
-		if ( this->text(column).length() < item->text(column).length() )
-			return 1;
-	}
+	int column = treeWidget()->sortColumn();
+	QString text1 = text(column);
+	QString text2 = item.text(column);
 
-	return key( column, ascending ).compare( item->key( column, ascending ) );
+	// Compare the numbers.
+	if (column < 2 && text1.length() != text2.length())
+		return text1.length() < text2.length();
+	return text1 < text2;
 }
 
 KChangeLVI::~KChangeLVI()
 {
 }
 
-KFileLVI::KFileLVI( K3ListView* parent, DiffModel* model ) : K3ListViewItem( parent )
+KFileLVI::KFileLVI( QTreeWidget* parent, DiffModel* model ) : QTreeWidgetItem( parent )
 {
 	m_model = model;
 
@@ -511,14 +518,13 @@ KFileLVI::KFileLVI( K3ListView* parent, DiffModel* model ) : K3ListViewItem( par
 
 	setText( 0, src );
 	setText( 1, dst );
-	setPixmap( 0, SmallIcon( getIcon( src ) ) );
-	setPixmap( 1, SmallIcon( getIcon( dst ) ) );
-	setSelectable( true );
+	setIcon( 0, SmallIcon( getIcon( src ) ) );
+	setIcon( 1, SmallIcon( getIcon( dst ) ) );
 }
 
 bool KFileLVI::hasExtension(const QString& extensions, const QString& fileName)
 {
-    QStringList extList = extensions.split(' ');
+	QStringList extList = extensions.split(' ');
 	foreach (const QString &ext, extList) {
 		if ( fileName.endsWith(ext, Qt::CaseInsensitive) ) {
 			return true;
@@ -591,13 +597,13 @@ const QString KFileLVI::getIcon(const QString& fileName)
 	return "text-plain";
 }
 
-void KFileLVI::fillChangesList( K3ListView* changesList, Q3PtrDict<KChangeLVI>* diffToChangeItemDict )
+void KFileLVI::fillChangesList( QTreeWidget* changesList, QHash<const Diff2::Difference*, KChangeLVI*>* diffToChangeItemDict )
 {
 	changesList->clear();
 	diffToChangeItemDict->clear();
 
-	DifferenceListConstIterator diffIt = m_model->differences()->begin();
-	DifferenceListConstIterator dEnd   = m_model->differences()->end();
+	DifferenceListConstIterator diffIt = m_model->differences()->constBegin();
+	DifferenceListConstIterator dEnd   = m_model->differences()->constEnd();
 
 	for ( ; diffIt != dEnd; ++diffIt )
 	{
@@ -605,47 +611,45 @@ void KFileLVI::fillChangesList( K3ListView* changesList, Q3PtrDict<KChangeLVI>*
 		diffToChangeItemDict->insert( *diffIt, change );
 	}
 
-	changesList->setSelected( changesList->firstChild(), true );
+	changesList->setCurrentItem( changesList->topLevelItem( 0 ) );
 }
 
 KFileLVI::~KFileLVI()
 {
 }
 
-KDirLVI::KDirLVI( K3ListView* parent, QString& dir ) : K3ListViewItem( parent )
+KDirLVI::KDirLVI( QTreeWidget* parent, QString& dir ) : QTreeWidgetItem( parent )
 {
-//	kDebug(8105) << "KDirLVI (K3ListView) constructor called with dir = " << dir << endl;
+//	kDebug(8105) << "KDirLVI (QTreeWidget) constructor called with dir = " << dir << endl;
 	m_rootItem = true;
 	m_dirName = dir;
-	setPixmap( 0, SmallIcon( "folder" ) );
-	setOpen( true );
-	setSelectable( true );
+	setIcon( 0, SmallIcon( "folder" ) );
+	setExpanded( true );
 	if ( m_dirName.isEmpty() )
 		setText( 0, i18n( "Unknown" ) );
 	else
 		setText( 0, m_dirName );
 }
 
-KDirLVI::KDirLVI( KDirLVI* parent, QString& dir ) : K3ListViewItem( parent )
+KDirLVI::KDirLVI( KDirLVI* parent, QString& dir ) : QTreeWidgetItem( parent )
 {
 //	kDebug(8105) << "KDirLVI (KDirLVI) constructor called with dir = " << dir << endl;
 	m_rootItem = false;
 	m_dirName = dir;
-	setPixmap( 0, SmallIcon( "folder" ) );
-	setOpen( true );
-	setSelectable( true );
+	setIcon( 0, SmallIcon( "folder" ) );
+	setExpanded( true );
 	setText( 0, m_dirName );
 }
 
 // addModel always removes it own path from the beginning
-void KDirLVI::addModel( QString& path, DiffModel* model, Q3PtrDict<KDirLVI>* modelToDirItemDict )
+void KDirLVI::addModel( QString& path, DiffModel* model, QHash<const Diff2::DiffModel*, KDirLVI*>* modelToDirItemDict )
 {
 //	kDebug(8105) << "KDirLVI::addModel called with path = " << path << " from KDirLVI with m_dirName = " << m_dirName << endl;
 
 	if ( !m_dirName.isEmpty() )
 	{
-		if ( path.find( m_dirName ) > -1 )
-			path = path.remove( path.find( m_dirName ), m_dirName.length() );
+		if ( path.indexOf( m_dirName ) > -1 )
+			path = path.remove( path.indexOf( m_dirName ), m_dirName.length() );
 	}
 
 //	kDebug(8105) << "Path after removal of own dir (\"" << m_dirName << "\") = " << path << endl;
@@ -658,7 +662,7 @@ void KDirLVI::addModel( QString& path, DiffModel* model, Q3PtrDict<KDirLVI>* mod
 
 	KDirLVI* child;
 
-	QString dir = path.mid( 0, path.find( "/", 0 ) + 1 );
+	QString dir = path.mid( 0, path.indexOf( "/", 0 ) + 1 );
 	child = findChild( dir );
 	if ( !child )
 	{
@@ -674,18 +678,22 @@ KDirLVI* KDirLVI::findChild( QString dir )
 {
 //	kDebug(8105) << "KDirLVI::findChild called with dir = " << dir << endl;
 	KDirLVI* child;
-	if ( ( child = static_cast<KDirLVI*>(this->firstChild()) ) != 0L )
+	if ( ( child = static_cast<KDirLVI*>(this->child(0)) ) != 0L )
 	{ // has children, check if dir already exists, if so addModel
-		do {
+		QTreeWidgetItemIterator it(child);
+		while (*it) {
+			child = static_cast<KDirLVI*>(*it);
+
 			if ( dir == child->dirName() )
 				return child;
-		} while ( ( child = static_cast<KDirLVI*>(child->nextSibling()) ) != 0L );
+			++it;
+		}
 	}
 
 	return 0L;
 }
 
-void KDirLVI::fillFileList( K3ListView* fileList, Q3PtrDict<KFileLVI>* modelToFileItemDict )
+void KDirLVI::fillFileList( QTreeWidget* fileList, QHash<const Diff2::DiffModel*, KFileLVI*>* modelToFileItemDict )
 {
 	fileList->clear();
 
@@ -697,7 +705,7 @@ void KDirLVI::fillFileList( K3ListView* fileList, Q3PtrDict<KFileLVI>* modelToFi
 		modelToFileItemDict->insert( *modelIt, file );
 	}
 
-	fileList->setSelected( fileList->firstChild(), true );
+	fileList->setCurrentItem( fileList->topLevelItem( 0 ) );
 }
 
 QString KDirLVI::fullPath( QString& path )
@@ -735,14 +743,18 @@ KDirLVI* KDirLVI::setSelected( QString dir )
 	{
 		return this;
 	}
-	KDirLVI* child = static_cast<KDirLVI*>(firstChild());
+	KDirLVI* child = static_cast<KDirLVI*>(this->child(0));
 	if ( !child )
 		return 0L;
 
-	do {
+	QTreeWidgetItemIterator it(child);
+	while (*it) {
+		child = static_cast<KDirLVI*>(*it);
+
 		if ( dir.startsWith( child->dirName() ) )
 			return child->setSelected( dir );
-	} while ( ( child = static_cast<KDirLVI*>(child->nextSibling()) ) != 0L );
+		++it;
+	}
 
 	return 0L;
 }
@@ -752,48 +764,17 @@ KDirLVI::~KDirLVI()
 	m_modelList.clear();
 }
 
-// part stuff
-KComponentData *KompareNavTreePartFactory::s_instance = 0L;
-KAboutData* KompareNavTreePartFactory::s_about = 0L;
-
-KompareNavTreePartFactory::KompareNavTreePartFactory()
-    : KParts::Factory()
+static KAboutData aboutData()
 {
+    KAboutData about("komparenavtreepart", 0, ki18n("KompareNavTreePart"), "1.2");
+    about.addAuthor(ki18n("John Firebaugh"), ki18n("Author"), "jfirebaugh@kde.org");
+    about.addAuthor(ki18n("Otto Bruggeman"), ki18n("Author"), "bruggie@gmail.com" );
+    return about;
 }
 
-KompareNavTreePartFactory::~KompareNavTreePartFactory()
-{
-	delete s_instance;
-	delete s_about;
-
-	s_instance = 0L;
-}
-
-KParts::Part* KompareNavTreePartFactory::createPartObject( QWidget* parentWidget,
-                                                  QObject* /*parent*/,
-                                                  const char* /*classname*/, const QStringList & /*args*/ )
-{
-	// Create an instance of our Part
-	KompareNavTreePart* obj = new KompareNavTreePart( parentWidget, 0 );
-
-	KGlobal::locale()->insertCatalog("kompare");
-
-	return obj;
-}
-
-const KComponentData &KompareNavTreePartFactory::componentData()
-{
-	if( !s_instance )
-	{
-		s_about = new KAboutData("komparenavtreepart", 0, ki18n("KompareNavTreePart"), "1.2");
-		s_about->addAuthor(ki18n("John Firebaugh"), ki18n("Author"), "jfirebaugh@kde.org");
-		s_about->addAuthor(ki18n("Otto Bruggeman"), ki18n("Author"), "bruggie@gmail.com" );
-		s_instance = new KComponentData(s_about);
-	}
-	return *s_instance;
-}
-
-K_EXPORT_COMPONENT_FACTORY( libkomparenavtreepart, KompareNavTreePartFactory )
-K_EXPORT_PLUGIN( KompareNavTreePartFactory )
+K_PLUGIN_FACTORY(KompareNavTreePartFactory,
+                 registerPlugin<KompareNavTreePart>();
+    )
+K_EXPORT_PLUGIN( KompareNavTreePartFactory(aboutData()) )
 
 #include "komparenavtreepart.moc"
