@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2008-2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2008-2011 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -25,6 +25,7 @@
 #include "actionproxy.h"
 #include "editortab.h"
 #include "projecttab.h"
+#include "jobs.h"
 #include "tmtab.h"
 #include "prefs_lokalize.h"
 
@@ -35,6 +36,8 @@
 #include "projectlocal.h"
 #include "prefs.h"
 
+#include "tools/widgettextcaptureconfig.h"
+
 #include "multieditoradaptor.h"
 
 #include <kglobal.h>
@@ -45,6 +48,7 @@
 #include <kstatusbar.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
+#include <knotification.h>
 #include <kapplication.h>
 
 
@@ -89,12 +93,15 @@ LokalizeMainWindow::LokalizeMainWindow()
     m_mdiArea->setViewMode(QMdiArea::TabbedView);
     m_mdiArea->setActivationOrder(QMdiArea::ActivationHistoryOrder);
     m_mdiArea->setDocumentMode(true);
+#if QT_VERSION >= 0x040800
+    m_mdiArea->setTabsMovable(true);
+#endif
 
     setCentralWidget(m_mdiArea);
     connect(m_mdiArea, SIGNAL(subWindowActivated(QMdiSubWindow*)),this,SLOT(slotSubWindowActivated(QMdiSubWindow*)));
     setupActions();
 
-     //prevent relayout of dockwidgets
+    //prevent relayout of dockwidgets
     m_mdiArea->setOption(QMdiArea::DontMaximizeSubWindowOnActivation,true);
 
     connect(Project::instance(), SIGNAL(configChanged()), this, SLOT(projectSettingsChanged()));
@@ -126,8 +133,15 @@ LokalizeMainWindow::LokalizeMainWindow()
 }
 void LokalizeMainWindow::initLater()
 {
-    if(!m_prevSubWindow)
+    if(!m_prevSubWindow && m_projectSubWindow)
         slotSubWindowActivated(m_projectSubWindow);
+
+    if(!Project::instance()->isTmSupported())
+    {
+        KNotification* notification=new KNotification("NoSqlModulesAvailable", this);
+        notification->setText( i18nc("@info","No Qt Sql modules were found. Translation memory will not work.") );
+        notification->sendEvent();
+    }
 }
 
 LokalizeMainWindow::~LokalizeMainWindow()
@@ -144,8 +158,11 @@ void LokalizeMainWindow::slotSubWindowActivated(QMdiSubWindow* w)
     if (!w || m_prevSubWindow==w)
         return;
 
+    w->setUpdatesEnabled(true);  //QTBUG-23289
+
     if (m_prevSubWindow)
     {
+        m_prevSubWindow->setUpdatesEnabled(false);
         LokalizeSubwindowBase* prevEditor=static_cast<LokalizeSubwindowBase2*>( m_prevSubWindow->widget() );
         prevEditor->hideDocks();
         guiFactory()->removeClient( prevEditor->guiClient()   );
@@ -225,7 +242,14 @@ bool LokalizeMainWindow::queryClose()
             return false;
     }
 
-    return true;
+    bool ok=Project::instance()->queryCloseForAuxiliaryWindows();
+    
+    if (ok)
+    {
+        TM::cancelAllJobs(); //this shit works l)
+        Project::instance()->model()->weaver()->dequeue();
+    }
+    return ok;
 }
 
 EditorTab* LokalizeMainWindow::fileOpen(KUrl url, int entry/*, int offset*/,bool setAsActive, const QString& mergeFile, bool silent)
@@ -275,6 +299,8 @@ EditorTab* LokalizeMainWindow::fileOpen(KUrl url, int entry/*, int offset*/,bool
         m_toBeActiveSubWindow=sw;
         QTimer::singleShot(0,this,SLOT(applyToBeActiveSubWindow()));
     }
+    else
+        sw->setUpdatesEnabled(false); //QTBUG-23289
 
     if (!mergeFile.isEmpty())
         w->mergeOpen(mergeFile);
@@ -315,7 +341,7 @@ void LokalizeMainWindow::editorClosed(QObject* obj)
 
 EditorTab* LokalizeMainWindow::fileOpen(const KUrl& url, const QString& source, const QString& ctxt)
 {
-    EditorTab* w=fileOpen(url);
+    EditorTab* w=fileOpen(url, 0, true);
     if (!w)
         return 0;//TODO message
     w->findEntryBySourceContext(source,ctxt);
@@ -331,6 +357,7 @@ QObject* LokalizeMainWindow::projectOverview()
         w->showMaximized();
         m_projectSubWindow->showMaximized();
         connect(w, SIGNAL(fileOpenRequested(KUrl)),this,SLOT(fileOpen(KUrl)));
+        connect(w, SIGNAL(projectOpenRequested(QString)),this,SLOT(openProject(QString)));
     }
     if (m_mdiArea->currentSubWindow()==m_projectSubWindow)
         return m_projectSubWindow->widget();
@@ -345,6 +372,12 @@ void LokalizeMainWindow::showProjectOverview()
 
 TM::TMTab* LokalizeMainWindow::showTM()
 {
+    if (!Project::instance()->isTmSupported())
+    {
+        KMessageBox::information(0, i18n("TM facility requires SQLite Qt module."), i18n("No SQLite module available"));
+        return 0;
+    }
+
     if (!m_translationMemorySubWindow)
     {
         TM::TMTab* w=new TM::TMTab(this);
@@ -394,7 +427,7 @@ void LokalizeMainWindow::setupActions()
 
 //Settings
     SettingsController* sc=SettingsController::instance();
-    KStandardAction::preferences(sc, SLOT(slotSettings()),ac);
+    KStandardAction::preferences(sc, SLOT(showSettingsDialog()),ac);
 
 #define ADD_ACTION_ICON(_name,_text,_shortcut,_icon)\
     action = actionCategory->addAction(_name);\
@@ -455,12 +488,15 @@ void LokalizeMainWindow::setupActions()
 
     action = proj->addAction("project_open",this,SLOT(openProject()));
     action->setText(i18nc("@action:inmenu","Open project"));
-
+    action->setIcon(KIcon("project-open"));
 
     m_openRecentProjectAction=new KRecentFilesAction(i18nc("@action:inmenu","Open recent project"),this);
     action = proj->addAction("project_open_recent",m_openRecentProjectAction);
     connect(m_openRecentProjectAction,SIGNAL(urlSelected(KUrl)),this,SLOT(openProject(KUrl)));
 
+    action = ac->addAction("tools_widgettextcapture",this,SLOT(widgetTextCapture()));
+    action->setText(i18n("Widget Text Capture"));
+
     //Qt::QueuedConnection: defer until event loop is running to eliminate QWidgetPrivate::showChildren(bool) startup crash
     connect(Project::instance(),SIGNAL(loaded()), this,SLOT(projectLoaded()), Qt::QueuedConnection);
 
@@ -481,7 +517,7 @@ bool LokalizeMainWindow::closeProject()
     int i=editors.size();
     while (--i>=0)
     {
-        if (editors.at(i)==m_translationMemorySubWindow)
+        if (editors.at(i)==m_translationMemorySubWindow && m_translationMemorySubWindow)
             editors.at(i)->deleteLater();
         else if (qobject_cast<EditorTab*>(editors.at(i)->widget()))
         {
@@ -497,20 +533,13 @@ bool LokalizeMainWindow::closeProject()
 
 void LokalizeMainWindow::openProject(QString path)
 {
-    if (path.isEmpty())
-    {
-        Project::instance()->model()->weaver()->suspend();
-        path=KFileDialog::getOpenFileName(KUrl()/*_catalog->url().directory()*/,
-                                          "*.lokalize *.ktp|lokalize translation project"/*"text/x-lokalize-project"*/,
-                                         0);
-        Project::instance()->model()->weaver()->resume();
-    }
+    path=SettingsController::instance()->projectOpen(path, false);//dry run
 
     if (path.isEmpty())
         return;
 
     if (closeProject())
-        SettingsController::instance()->projectOpen(path);
+        SettingsController::instance()->projectOpen(path, true);//really open
 }
 
 void LokalizeMainWindow::saveProperties(KConfigGroup& stateGroup)
@@ -617,8 +646,11 @@ void LokalizeMainWindow::projectLoaded()
     //QList<int> offsets;
     QList<int> entries;
 
-    ProjectTab *w = static_cast<ProjectTab*>(m_projectSubWindow->widget());
-    w->setLegacyUnitsCount(projectStateGroup.readEntry("UnitsCount", 0));
+    if (m_projectSubWindow)
+    {
+        ProjectTab *w = static_cast<ProjectTab*>(m_projectSubWindow->widget());
+        w->setLegacyUnitsCount(projectStateGroup.readEntry("UnitsCount", 0));
+    }
 
     entries=projectStateGroup.readEntry("Entries",entries);
 
@@ -640,13 +672,9 @@ void LokalizeMainWindow::projectLoaded()
         kDebug()<<"failedFiles"<<failedFiles;
 //         KMessageBox::error(this, i18nc("@info","Error opening the following files:")+
 //                                 "<br><il><li><filename>"+failedFiles.join("</filename></li><li><filename>")+"</filename></li></il>" );
-        KDialog* dialog=new KDialog(this);
-        dialog->setAttribute(Qt::WA_DeleteOnClose,true);
-        dialog->showButton(KDialog::Ok,true);
-        dialog->showButton(KDialog::Cancel,false);
-        KMessageBox::createKMessageBox(dialog, QIcon(), i18nc("@info","Error opening the following files:"),
-                failedFiles, QString(), 0, KMessageBox::NoExec, QString(), QMessageBox::Warning);
-        dialog->show();
+        KNotification* notification=new KNotification("FilesOpenError", this);
+        notification->setText( i18nc("@info","Error opening the following files:\n\n")%"<filename>"%failedFiles.join("</filename><br><filename>")%"</filename>" );
+        notification->sendEvent();
     }
 
     if (files.isEmpty() && dockWidgets.size() > 0)
@@ -665,9 +693,15 @@ void LokalizeMainWindow::projectLoaded()
 
 void LokalizeMainWindow::projectSettingsChanged()
 {
+    //TODO show langs
     setCaption(Project::instance()->projectID());
 }
 
+void LokalizeMainWindow::widgetTextCapture()
+{
+    WidgetTextCaptureConfig* w=new WidgetTextCaptureConfig(this);
+    w->show();
+}
 
 //BEGIN DBus interface
 
@@ -920,6 +954,25 @@ void MultiEditorAdaptor::handleParentDestroy(QObject* p)
 
 
 
+DelayedFileOpener::DelayedFileOpener(const KUrl::List& urls, LokalizeMainWindow* lmw)
+ : QObject()
+ , m_urls(urls)
+ , m_lmw(lmw)
+{
+    //do the work just after project load handlind is finished
+    //(i.e. all the files from previous project session are loaded)
+    QTimer::singleShot(1,this,SLOT(doOpen()));
+}
+
+void DelayedFileOpener::doOpen()
+{
+    int lastIndex=m_urls.count()-1;
+    for (int i=0;i<=lastIndex;i++)
+        m_lmw->fileOpen(m_urls.at(i), 0, /*set as active*/i==lastIndex);
+    deleteLater();
+}
+
+
 #include "lokalizemainwindow.moc"
  //these have to be included somewhere ;)
 #include "lokalizesubwindowbase.moc"
