@@ -1,11 +1,10 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,21 +13,21 @@
 
 #include <QtGui/QUndoCommand>
 
-#include "umlobject.h"
+class UMLObject;
 
 namespace Uml
 {
     class CmdCreateUMLObject : public QUndoCommand
     {
-        public:
-            CmdCreateUMLObject(UMLObject* o);
-            ~CmdCreateUMLObject();
+    public:
+        CmdCreateUMLObject(UMLObject* o);
+        ~CmdCreateUMLObject();
 
-            void redo();
-            void undo();
+        void redo();
+        void undo();
 
-        private:
-            UMLObject*  m_obj;
+    private:
+        UMLObject*  m_obj;
     };
 }
 
