@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2009-2009                                               *
+ *   copyright (C) 2009-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -17,13 +17,11 @@
 #include "association.h"
 #include "attribute.h"
 #include "classifier.h"
+#include "debug_utils.h"
 #include "folder.h"
 #include "operation.h"
 #include "uml.h"
 #include "umldoc.h"
-#include "umlnamespace.h"
-
-#include <kdebug.h>
 
 #include <QtCore/QRegExp>
 #include <QtCore/QTextStream>
@@ -189,7 +187,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
         return;
     }
 
-    QString classname = cleanName(c->getName());
+    QString classname = cleanName(c->name());
     //find an appropriate name for our file
     QString fileName = findFileName(c, ".vala");
     if (fileName.isEmpty()) {
@@ -217,8 +215,8 @@ void ValaWriter::writeClass(UMLClassifier *c)
         cs << str << m_endl;
     }
 
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    UMLFolder *logicalView = umldoc->getRootFolder(Uml::mt_Logical);
+    UMLDoc *umldoc = UMLApp::app()->document();
+    UMLFolder *logicalView = umldoc->rootFolder(Uml::ModelType::Logical);
 
     // write generic includes
     //cs << "using GLib;" << m_endl;
@@ -227,7 +225,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
     cs << "using GLib;" << m_endl << m_endl;
 
     //write includes and namespace
-    UMLPackage *container = c->getUMLPackage();
+    UMLPackage *container = c->umlPackage();
     if (container == logicalView) {
         container = NULL;
     }
@@ -240,10 +238,10 @@ void ValaWriter::writeClass(UMLClassifier *c)
         foreach ( UMLPackage* p , includes ) {
             UMLClassifier *cl = dynamic_cast<UMLClassifier*>(p);
             if (cl) {
-                p = cl->getUMLPackage();
+                p = cl->umlPackage();
             }
             if (p != logicalView && m_seenIncludes.indexOf(p) == -1 && p != container) {
-                cs << "using " << p->getFullyQualifiedName(".") << ";" << m_endl;
+                cs << "using " << p->fullyQualifiedName(".") << ";" << m_endl;
                 m_seenIncludes.append(p);
             }
         }
@@ -253,20 +251,20 @@ void ValaWriter::writeClass(UMLClassifier *c)
     m_container_indent = "";
 
     if (container) {
-        cs << "namespace " << container->getFullyQualifiedName(".") << m_endl;
+        cs << "namespace " << container->fullyQualifiedName(".") << m_endl;
         cs << "{" << m_endl << m_endl;
         m_container_indent = m_indentation;
         m_seenIncludes.append(container);
     }
 
     //Write class Documentation if there is somthing or if force option
-    if (forceDoc() || !c->getDoc().isEmpty()) {
+    if (forceDoc() || !c->doc().isEmpty()) {
         cs << m_container_indent << "/**" << m_endl;
-        if (c->getDoc().isEmpty()) {
-            cs << formatDoc(c->getDoc(), m_container_indent + " * TODO: Add documentation here." );
+        if (c->doc().isEmpty()) {
+            cs << formatDoc(c->doc(), m_container_indent + " * TODO: Add documentation here." );
         }
         else {
-            cs << formatDoc(c->getDoc(), m_container_indent + m_indentation + " * ");
+            cs << formatDoc(c->doc(), m_container_indent + m_indentation + " * ");
         }
         cs << m_container_indent << " */" << m_endl ;
     }
@@ -286,7 +284,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
     }
     else {
         //check if class is abstract and / or has abstract methods
-        if (c->getAbstract() || c->hasAbstractOps()) {
+        if (c->isAbstract() || c->hasAbstractOps()) {
             cs << "abstract ";
         }
 
@@ -300,7 +298,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
                     if (supers > 0) {
                         cs << " // AND ";
                     }
-                    cs << cleanName(obj->getName());
+                    cs << cleanName(obj->name());
                     supers++;
                 }
             }
@@ -316,7 +314,7 @@ void ValaWriter::writeClass(UMLClassifier *c)
                 UMLClassifier *real = (UMLClassifier*)a->getObject(Uml::B);
                 if(real != c) {
                     // write list of realizations
-                    cs << ", " << real->getName();
+                    cs << ", " << real->name();
                 }
             }
         }
@@ -351,12 +349,13 @@ void ValaWriter::writeClass(UMLClassifier *c)
 
     if (container) {
         cs << "}  // end of namespace "
-            << container->getFullyQualifiedName(".") << m_endl << m_endl;
+            << container->fullyQualifiedName(".") << m_endl << m_endl;
     }
 
     //close files and notfiy we are done
     filecs.close();
     emit codeGenerated(c, true);
+    emit showGeneratedFile(filecs.fileName());
 }
 
 ////////////////////////////////////////////////////////////////////////////////////
@@ -378,7 +377,7 @@ void ValaWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
     //sort operations by scope first and see if there are abstract methods
     UMLOperationList opl(c->getOpList());
     foreach (UMLOperation* op,  opl ) {
-        switch (op->getVisibility()) {
+        switch (op->visibility()) {
           case Uml::Visibility::Public:
             oppub.append(op);
             break;
@@ -424,7 +423,7 @@ void ValaWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
     // write superclasses abstract methods
     UMLClassifierList superclasses = c->getSuperClasses();
 
-    if (!isInterface && !c->getAbstract() && !c->hasAbstractOps() && superclasses.count() > 0) {
+    if (!isInterface && !c->isAbstract() && !c->hasAbstractOps() && superclasses.count() > 0) {
         writeOverridesRecursive(&superclasses, cs);
     }
 
@@ -445,13 +444,13 @@ void ValaWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTextS
             // collect abstract ops
             UMLOperationList opl(obj->getOpList());
             foreach (UMLOperation* op, opl ) {
-                if (op->getAbstract()) {
+                if (op->isAbstract()) {
                     opabstract.append(op);
                 }
             }
 
             // write abstract implementations
-            cs << m_endl << m_container_indent << m_indentation << "//region " << obj->getName() << " members" << m_endl << m_endl;
+            cs << m_endl << m_container_indent << m_indentation << "//region " << obj->name() << " members" << m_endl << m_endl;
             writeOperations(opabstract,cs,false,true,true);
             cs << m_container_indent << m_indentation << "//endregion" << m_endl << m_endl;
 
@@ -489,7 +488,7 @@ void ValaWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAsso
         UMLOperationList opreal = real->getOpList();
 
         // write realizations
-        cs << m_endl << m_container_indent << m_indentation << "//region " << real->getName() << " members" << m_endl << m_endl;
+        cs << m_endl << m_container_indent << m_indentation << "//region " << real->name() << " members" << m_endl << m_endl;
         writeOperations(opreal,cs,false,false,true);
         cs << m_container_indent << m_indentation << "//endregion" << m_endl << m_endl;
 
@@ -517,28 +516,28 @@ void ValaWriter::writeOperations(UMLOperationList opList,
         UMLAttributeList atl = op->getParmList();
 
         //write method doc if we have doc || if at least one of the params has doc
-        bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
+        bool writeDoc = forceDoc() || !op->doc().isEmpty();
 
         foreach ( UMLAttribute* at, atl ) {
-            writeDoc |= !at->getDoc().isEmpty();
+            writeDoc |= !at->doc().isEmpty();
         }
 
         //write method documentation
         if (writeDoc && !isOverride) {
             cs << m_container_indent << m_indentation << "/**" << m_endl;
-            if (op->getDoc().isEmpty()) {
-                cs << formatDoc(op->getDoc(), m_container_indent + m_indentation + " * TODO: Add documentation here. ");
+            if (op->doc().isEmpty()) {
+                cs << formatDoc(op->doc(), m_container_indent + m_indentation + " * TODO: Add documentation here. ");
             }
             else {
-                cs << formatDoc(op->getDoc(), m_container_indent + m_indentation + " * ");
+                cs << formatDoc(op->doc(), m_container_indent + m_indentation + " * ");
             }
-            
+
             //write parameter documentation
             foreach ( UMLAttribute* at, atl ) {
-                if (forceDoc() || !at->getDoc().isEmpty()) {
-                    cs << m_container_indent << m_indentation << " * @param " << cleanName(at->getName()) << "";
+                if (forceDoc() || !at->doc().isEmpty()) {
+                    cs << m_container_indent << m_indentation << " * @param " << cleanName(at->name()) << "";
                     //removing newlines from parameter doc
-                    cs << formatDoc(at->getDoc(), "").replace('\n', ' ').remove('\r').remove(QRegExp(" $"));
+                    cs << formatDoc(at->doc(), "").replace('\n', ' ').remove('\r').remove(QRegExp(" $"));
                     cs << m_endl;
                 }
             }
@@ -556,18 +555,18 @@ void ValaWriter::writeOperations(UMLOperationList opList,
         cs << m_container_indent << m_indentation;
         if (!isInterface) {
             if (!isOverride) {
-                if (op->getAbstract()) {
+                if (op->isAbstract()) {
                     cs << "abstract ";
                 }
-                cs << op->getVisibility().toString() << " ";
-                if (op->getStatic()) {
+                cs << op->visibility().toString() << " ";
+                if (op->isStatic()) {
                     cs << "static ";
                 }
             }
             else {
                 // method overriding an abstract parent
-                cs << op->getVisibility().toString() << " override ";
-                if (op->getStatic()) {
+                cs << op->visibility().toString() << " override ";
+                if (op->isStatic()) {
                     cs << "static ";
                 }
             }
@@ -584,14 +583,14 @@ void ValaWriter::writeOperations(UMLOperationList opList,
         }
 
         // method name
-        cs << cleanName(op->getName()) << "(";
+        cs << cleanName(op->name()) << "(";
 
         // method parameters
         int i= atl.count();
         int j=0;
         for (UMLAttributeListIt atlIt( atl ); atlIt.hasNext(); ++j) {
             UMLAttribute* at = atlIt.next();
-            cs << makeLocalTypeName(at) << " " << cleanName(at->getName());
+            cs << makeLocalTypeName(at) << " " << cleanName(at->name());
 
             // no initial values in Vala
             //<< (!(at->getInitialValue().isEmpty()) ?
@@ -602,7 +601,7 @@ void ValaWriter::writeOperations(UMLOperationList opList,
         cs << ")";
 
         //FIXME: how to control generation of error stub?
-        if (!isInterface && (!op->getAbstract() || isOverride)) {
+        if (!isInterface && (!op->isAbstract() || isOverride)) {
             cs << m_endl << m_container_indent << m_indentation << "{" << m_endl;
             // write source code of operation else throw not implemented exception
             QString sourceCode = op->getSourceCode();
@@ -643,7 +642,7 @@ void ValaWriter::writeAttributes(UMLClassifier *c, QTextStream &cs)
     foreach ( UMLAttribute* at, atl ) {
         if (!at->getInitialValue().isEmpty())
             atdefval.append(at);
-        switch (at->getVisibility()) {
+        switch (at->visibility()) {
           case Uml::Visibility::Public:
             atpub.append(at);
             break;
@@ -692,11 +691,11 @@ void ValaWriter::writeAttributes(UMLAttributeList &atList, QTextStream &cs)
     foreach (UMLAttribute* at, atList ) {
 
         bool asProperty = true;
-        if (at->getVisibility() == Uml::Visibility::Private) {
+        if (at->visibility() == Uml::Visibility::Private) {
             asProperty = false;
         }
-        writeAttribute(at->getDoc(), at->getVisibility(), at->getStatic(),
-            makeLocalTypeName(at), at->getName(), at->getInitialValue(), asProperty, cs);
+        writeAttribute(at->doc(), at->visibility(), at->isStatic(),
+            makeLocalTypeName(at), at->name(), at->getInitialValue(), asProperty, cs);
 
         cs << m_endl;
     } // end for
@@ -723,7 +722,7 @@ void ValaWriter::writeAssociatedAttributes(UMLAssociationList &associated, UMLCl
         }
         // Take name and documentaton from Role, take type name from the referenced object
         QString roleName = cleanName(a->getRoleName(Uml::B));
-        QString typeName = cleanName(o->getName());
+        QString typeName = cleanName(o->name());
         if (roleName.isEmpty()) {
             roleName = QString("UnnamedRoleB_%1").arg(m_unnamedRoles++);
         }
@@ -820,9 +819,9 @@ void ValaWriter::writeAttribute(const QString& doc,
  */
 QString ValaWriter::makeLocalTypeName(UMLClassifierListItem *cl)
 {
-    UMLPackage *p = cl->getType()->getUMLPackage();
+    UMLPackage *p = cl->getType()->umlPackage();
     if (m_seenIncludes.indexOf(p) != -1) {
-        return cl->getType()->getName();
+        return cl->getType()->name();
     }
     else {
         return cl->getTypeName();
@@ -833,16 +832,16 @@ QString ValaWriter::makeLocalTypeName(UMLClassifierListItem *cl)
  * Returns "Vala".
  * @return programming language id
  */
-Uml::Programming_Language ValaWriter::getLanguage()
+Uml::ProgrammingLanguage ValaWriter::language() const
 {
-    return Uml::pl_Vala;
+    return Uml::ProgrammingLanguage::Vala;
 }
 
 /**
  * Get list of reserved keywords.
  * @return list of reserved keywords
  */
-const QStringList ValaWriter::reservedKeywords() const
+QStringList ValaWriter::reservedKeywords() const
 {
     static QStringList keywords;
 
