@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2009                                               *
+ *   copyright (C) 2006-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,6 +14,8 @@
 // app includes
 #include "attribute.h"
 #include "classifier.h"
+#include "codeimpthread.h"
+#include "debug_utils.h"
 #include "enum.h"
 #include "import_utils.h"
 #include "operation.h"
@@ -22,9 +24,6 @@
 #include "umldoc.h"
 #include "umlpackagelist.h"
 
-// kde includes
-#include <kdebug.h>
-
 // qt includes
 #include <QtCore/QFile>
 #include <QtCore/QTextStream>
@@ -37,7 +36,8 @@ int JavaImport::s_parseDepth = 0;
 /**
  * Constructor.
  */
-JavaImport::JavaImport() : NativeImportBase("//")
+JavaImport::JavaImport(CodeImpThread* thread)
+  : NativeImportBase("//", thread)
 {
     setMultiLineComment("/*", "*/");
     initVars();
@@ -67,17 +67,19 @@ void JavaImport::initVars()
 QString JavaImport::joinTypename(const QString& typeName)
 {
     QString typeNameRet(typeName);
-    if (m_source[m_srcIndex + 1] == "<" ||
-        m_source[m_srcIndex + 1] == "[") {
-        int start = ++m_srcIndex;
-        if (! skipToClosing(m_source[start][0]))
-            return typeNameRet;
-        for (int i = start; i <= m_srcIndex; ++i) {
-            typeNameRet += m_source[i];
+    if (m_srcIndex + 1 < m_source.size()) {
+        if (m_source[m_srcIndex + 1] == "<" ||
+            m_source[m_srcIndex + 1] == "[") {
+            int start = ++m_srcIndex;
+            if (! skipToClosing(m_source[start][0]))
+                return typeNameRet;
+            for (int i = start; i <= m_srcIndex; ++i) {
+                typeNameRet += m_source[i];
+            }
         }
     }
     // to handle multidimensional arrays, call recursively
-    if (m_source[m_srcIndex + 1] == "[") {
+    if ((m_srcIndex + 1 < m_source.size()) && (m_source[m_srcIndex + 1] == "[")) {
         typeNameRet = joinTypename( typeNameRet );
     }
     return typeNameRet;
@@ -135,8 +137,8 @@ void JavaImport::spawnImport(const QString& file )
  */
 UMLObject* JavaImport::findObject(const QString& name, UMLPackage *parentPkg)
 {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    UMLObject * o = umldoc->findUMLObject(name, Uml::ot_UMLObject , parentPkg);
+    UMLDoc *umldoc = UMLApp::app()->document();
+    UMLObject * o = umldoc->findUMLObject(name, UMLObject::ot_UMLObject , parentPkg);
     return o;
 }
 
@@ -176,7 +178,7 @@ UMLObject* JavaImport::resolveClass (const QString& className)
         if ( isArray ) {
             // we have imported the type. For arrays we want to return
             // the array type
-            return Import_Utils::createUMLObject(Uml::ot_Class, className, m_scope[m_scopeIndex]);
+            return Import_Utils::createUMLObject(UMLObject::ot_Class, className, m_scope[m_scopeIndex]);
         }
         return findObject(baseClassName, m_scope[m_scopeIndex]);
     }
@@ -187,6 +189,11 @@ UMLObject* JavaImport::resolveClass (const QString& className)
     QStringList package = m_currentPackage.split( '.' );
     int dirsInPackageCount = package.size();
 
+    // in case the path does not fit into the package hierachy 
+    // we cannot check the imports 
+    if (dirsInPackageCount >= file.size())
+        return NULL; 
+
     for (int count=0; count < dirsInPackageCount; ++count ) {
         // pop off one by one the directories, until only the source root remains
         //
@@ -214,7 +221,7 @@ UMLObject* JavaImport::resolveClass (const QString& className)
 
                 for (QStringList::Iterator it = split.begin(); it != split.end(); ++it) {
                     QString name = (*it);
-                    UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Package,
+                    UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Package,
                                                                   name, parent);
                     current = static_cast<UMLPackage*>(ns);
                     parent = current;
@@ -222,7 +229,7 @@ UMLObject* JavaImport::resolveClass (const QString& className)
                 if ( isArray ) {
                     // we have imported the type. For arrays we want to return
                     // the array type
-                    return Import_Utils::createUMLObject(Uml::ot_Class, className, current);
+                    return Import_Utils::createUMLObject(UMLObject::ot_Class, className, current);
                 }
                 // now that we have the right package, the class should be findable
                 return findObject(baseClassName, current);
@@ -236,9 +243,9 @@ UMLObject* JavaImport::resolveClass (const QString& className)
  * Keep track of the current file being parsed and reset the list of imports.
  * @param filename   the name of the file being parsed
  */
-void JavaImport::parseFile(const QString& filename)
+bool JavaImport::parseFile(const QString& filename)
 {
-    m_currentFileName= filename;
+    m_currentFileName = filename;
     m_imports.clear();
     // default visibility is Impl, unless we are an interface, then it is
     // public for member vars and methods
@@ -256,6 +263,7 @@ void JavaImport::parseFile(const QString& filename)
         s_filesAlreadyParsed.clear();
         s_parseDepth = 0;
     }
+    return true;
 }
 
 /**
@@ -265,7 +273,7 @@ void JavaImport::parseFile(const QString& filename)
 bool JavaImport::parseStmt()
 {
     const int srcLength = m_source.count();
-    const QString& keyword = m_source[m_srcIndex];
+    QString keyword = m_source[m_srcIndex];
     //uDebug() << '"' << keyword << '"';
     if (keyword == "package") {
         m_currentPackage = advance();
@@ -273,7 +281,8 @@ bool JavaImport::parseStmt()
         const QStringList names = qualifiedName.split('.');
         for (QStringList::ConstIterator it = names.begin(); it != names.end(); ++it) {
             QString name = (*it);
-            UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Package,
+            log(keyword + ' ' + name);
+            UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Package,
                             name, m_scope[m_scopeIndex], m_comment);
             m_scope[++m_scopeIndex] = static_cast<UMLPackage*>(ns);
         }
@@ -285,7 +294,8 @@ bool JavaImport::parseStmt()
     }
     if (keyword == "class" || keyword == "interface") {
         const QString& name = advance();
-        const Uml::Object_Type t = (keyword == "class" ? Uml::ot_Class : Uml::ot_Interface);
+        const UMLObject::ObjectType t = (keyword == "class" ? UMLObject::ot_Class : UMLObject::ot_Interface);
+        log(keyword + ' ' + name);
         UMLObject *ns = Import_Utils::createUMLObject(t, name, m_scope[m_scopeIndex], m_comment);
         m_scope[++m_scopeIndex] = m_klass = static_cast<UMLClassifier*>(ns);
         m_klass->setAbstract(m_isAbstract);
@@ -294,7 +304,7 @@ bool JavaImport::parseStmt()
         // The UMLObject found by createUMLObject might originally have been created as a
         // placeholder with a type of class but if is really an interface, then we need to
         // change it.
-        Uml::Object_Type ot = (keyword == "interface" ? Uml::ot_Interface : Uml::ot_Class);
+        UMLObject::ObjectType ot = (keyword == "interface" ? UMLObject::ot_Interface : UMLObject::ot_Class);
         m_klass->setBaseType(ot);
         m_isAbstract = m_isStatic = false;
         // if no modifier is specified in an interface, then it means public
@@ -370,7 +380,8 @@ bool JavaImport::parseStmt()
     }
     if (keyword == "enum") {
         const QString& name = advance();
-        UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Enum,
+        log(keyword + ' ' + name);
+        UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Enum,
                         name, m_scope[m_scopeIndex], m_comment);
         UMLEnum *enumType = static_cast<UMLEnum*>(ns);
         skipStmt("{");
@@ -458,12 +469,28 @@ bool JavaImport::parseStmt()
             uError() << "importJava: too many }";
         return true;
     }
+    if (keyword == "<") {  // @todo generic parameters
+        if (! skipToClosing('<')) {
+            uError() << "importJava(" << keyword << "): template syntax error";
+            return false;
+        }
+        advance();
+        if (m_srcIndex == srcLength)
+            return false;
+	keyword = m_source[m_srcIndex];
+    }
     // At this point, we expect `keyword' to be a type name
     // (of a member of class or interface, or return type
     // of an operation.) Up next is the name of the attribute
     // or operation.
     if (! keyword.contains( QRegExp("^\\w") )) {
-        uError() << "importJava: ignoring " << keyword;
+	if (m_klass) {
+            uError() << "importJava: ignoring " << keyword <<
+                " at " << m_srcIndex << ", " << m_source.count() << " in " << m_klass->name();
+	} else {
+            uError() << "importJava: ignoring " << keyword <<
+                " at " << m_srcIndex << ", " << m_source.count() << " (outside class)";
+	}
         return false;
     }
     QString typeName = m_source[m_srcIndex];
@@ -475,7 +502,7 @@ bool JavaImport::parseStmt()
     }
     QString name = advance();
     QString nextToken;
-    if (typeName == m_klass->getName() && name == "(") {
+    if (typeName == m_klass->name() && name == "(") {
         // Constructor.
         nextToken = name;
         name = typeName;
@@ -503,7 +530,7 @@ bool JavaImport::parseStmt()
             UMLObject *obj = resolveClass(typeName);
             if (obj) {
                 // by prepending the package, unwanted placeholder types will not get created
-                typeName = obj->getFullyQualifiedName(".");
+                typeName = obj->fullyQualifiedName(".");
             }
             /* UMLAttribute *att = */ Import_Utils::addMethodParameter(op, typeName, parName);
             if (advance() != ",")
@@ -514,7 +541,7 @@ bool JavaImport::parseStmt()
         UMLObject *obj = resolveClass(typeName);
         if (obj) {
             // using the fully qualified name means that a placeholder type will not be created.
-            typeName = obj->getFullyQualifiedName(".");
+            typeName = obj->fullyQualifiedName(".");
         }
         Import_Utils::insertMethod(m_klass, op, m_currentAccess, typeName,
                                    m_isStatic, m_isAbstract, false /*isFriend*/,
@@ -559,16 +586,20 @@ bool JavaImport::parseStmt()
                 name += nextToken;  // add possible array dimensions to `name'
             }
             nextToken = advance();
+            if (nextToken.isEmpty()) {
+                break;
+            }
         }
         // try to resolve the class type, or create a placeholder if that fails
         UMLObject *type = resolveClass( typeName );
-        UMLObject *o;
         if (type) {
-            o = Import_Utils::insertAttribute(m_klass, m_currentAccess, name,
-                                           static_cast<UMLClassifier*>(type), m_comment, m_isStatic);
+            Import_Utils::insertAttribute(
+                        m_klass, m_currentAccess, name,
+                        static_cast<UMLClassifier*>(type), m_comment, m_isStatic);
         } else {
-            o = Import_Utils::insertAttribute(m_klass, m_currentAccess, name,
-                                                  typeName, m_comment, m_isStatic);
+            Import_Utils::insertAttribute(
+                        m_klass, m_currentAccess, name,
+                        typeName, m_comment, m_isStatic);
         }
         // UMLAttribute *attr = static_cast<UMLAttribute*>(o);
         if (nextToken != ",") {
@@ -581,11 +612,15 @@ bool JavaImport::parseStmt()
     }
     // reset visibility to default
     m_currentAccess = m_defaultCurrentAccess;
-    if (m_source[m_srcIndex] != ";") {
-        uError() << "importJava: ignoring trailing items at " << name;
+    if (m_srcIndex < m_source.count()) {
+        if (m_source[m_srcIndex] != ";") {
+            uError() << "importJava: ignoring trailing items at " << name;
+            skipStmt();
+        }
+    }
+    else {
+        uError() << "index out of range: ignoring statement " << name;
         skipStmt();
     }
     return true;
 }
-
-
